@@ -1,6 +1,6 @@
 package Ubic::Admin::Setup;
 BEGIN {
-  $Ubic::Admin::Setup::VERSION = '1.33';
+  $Ubic::Admin::Setup::VERSION = '1.34';
 }
 
 # ABSTRACT: this module handles ubic setup: asks user some questions and configures your system
@@ -12,6 +12,7 @@ use warnings;
 use Getopt::Long 2.33;
 use Carp;
 use IPC::Open3;
+use File::Path;
 
 use Ubic::AtomicFile;
 use Ubic::Settings;
@@ -20,6 +21,28 @@ use Ubic::Settings::ConfigFile;
 my $batch_mode;
 my $quiet;
 
+sub _defaults {
+    if ($^O eq 'freebsd') {
+        return (
+            config => '/usr/local/etc/ubic/ubic.cfg',
+            data_dir => '/var/db/ubic',
+            service_dir => '/usr/local/etc/ubic/service',
+            log_dir => '/var/log/ubic',
+            example => '/usr/local/etc, /var',
+        );
+    }
+    else {
+        # fhs
+        return (
+            config => '/etc/ubic/ubic.cfg',
+            data_dir => '/var/lib/ubic',
+            service_dir => '/etc/ubic/service',
+            log_dir => '/var/log/ubic',
+            example => '/etc, /var',
+        );
+    }
+};
+
 sub print_tty {
     print @_ unless $quiet or $batch_mode;
 }
@@ -125,6 +148,8 @@ sub setup {
 
     die "Unexpected arguments '@ARGV'" if @ARGV;
 
+    my %defaults = _defaults();
+
     eval { Ubic::Settings->check_settings };
     unless ($@) {
         my $go = prompt_bool("Looks like ubic is already configured, do you want to reconfigure?", $opt_reconfigure);
@@ -132,7 +157,7 @@ sub setup {
         print_tty "\n";
     }
 
-    print_tty "Ubic can be installed either in your home dir or into standard system paths (/etc, /var).\n";
+    print_tty "Ubic can be installed either in your home dir or into standard system paths ($defaults{example}).\n";
     print_tty "You need to be root to install it into system.\n";
 
     # ideally, we want is_root option and local option to be orthogonal
@@ -162,19 +187,31 @@ sub setup {
     }
 
     print_tty "\nService dir is a directory with descriptions of your services.\n";
-    my $default_service_dir = (defined($local_dir) ? "$local_dir/ubic/service" : '/etc/ubic/service');
+    my $default_service_dir = (
+        defined($local_dir)
+        ? "$local_dir/ubic/service"
+        : $defaults{service_dir}
+    );
     $default_service_dir = $opt_service_dir if defined $opt_service_dir;
     my $service_dir = prompt_str("Service dir?", $default_service_dir);
 
     print_tty "\nData dir is a directory into which ubic stores all of its data: locks,\n";
     print_tty "status files, tmp files.\n";
-    my $default_data_dir = (defined($local_dir) ? "$local_dir/ubic/data" : '/var/lib/ubic');
+    my $default_data_dir = (
+        defined($local_dir)
+        ? "$local_dir/ubic/data"
+        : $defaults{data_dir}
+    );
     $default_data_dir = $opt_data_dir if defined $opt_data_dir;
     my $data_dir = prompt_str("Data dir?", $default_data_dir);
 
     print_tty "\nLog dir is a directory into which ubic.watchdog will write its logs.\n";
     print_tty "(Your own services are free to write logs wherever they want.)\n";
-    my $default_log_dir = (defined($local_dir) ? "$local_dir/ubic/log" : '/var/log/ubic');
+    my $default_log_dir = (
+        defined($local_dir)
+        ? "$local_dir/ubic/log"
+        : $defaults{log_dir}
+    );
     $default_log_dir = $opt_log_dir if defined $opt_log_dir;
     my $log_dir = prompt_str("Log dir?", $default_log_dir);
 
@@ -226,10 +263,15 @@ sub setup {
         print_tty "there are any problems with their statuses.\n";
         print_tty "It is very simple and robust, but since it's important that watchdog never\n";
         print_tty "goes down, we recommended to install the cron job which checks watchdog itself.\n";
+        print_tty "Also, this cron job will bring watchdog and all other services online on host reboots.\n";
         $enable_crontab = prompt_bool("Install watchdog's watchdog as a cron job?", $opt_crontab);
     }
 
-    my $config_file = ($local_dir ? "$local_dir/.ubic.cfg" : '/etc/ubic/ubic.cfg');
+    my $config_file = (
+        defined($local_dir)
+        ?  "$local_dir/.ubic.cfg"
+        : $defaults{config}
+    );
 
     {
         print_tty "\nThat's all I need to know.\n";
@@ -241,18 +283,16 @@ sub setup {
 
     print "Installing dirs...\n";
 
-    xsystem('mkdir', '-p', '--', $service_dir);
-    xsystem('mkdir', '-p', '--', $data_dir);
-    xsystem('mkdir', '-p', '--', $log_dir);
+    mkpath($_) for ($service_dir, $data_dir, $log_dir);
 
     for my $subdir (qw[
         status simple-daemon/pid lock ubic-daemon tmp watchdog/lock watchdog/status
     ]) {
-        xsystem('mkdir', '-p', '--', "$data_dir/$subdir");
-        xsystem('chmod', '1777', '--', "$data_dir/$subdir") if $enable_1777;
+        mkpath("$data_dir/$subdir");
+        chmod(01777, "$data_dir/$subdir") or die "chmod failed: $!";
     }
 
-    xsystem('mkdir', '-p', '--', "$service_dir/ubic");
+    mkpath("$service_dir/ubic");
 
     if ($install_services) {
         my $add_service = sub {
@@ -339,7 +379,7 @@ Ubic::Admin::Setup - this module handles ubic setup: asks user some questions an
 
 =head1 VERSION
 
-version 1.33
+version 1.34
 
 =head1 DESCRPITION
 
